using System;
using System.IO;
using System.Data;
using System.Data.OleDb;
using System.Configuration;
using System.Collections;
using System.Linq;
using System.Text;
using System.Xml;
using System.Drawing;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using Korzh.EasyQuery;
using Korzh.EasyQuery.Db;
using Korzh.Utils.Db;

public partial class QueryMainForm : System.Web.UI.Page
{
    private System.Data.OleDb.OleDbConnection DbConnection = null;

    private string baseDataPath = null;

    protected void Page_Init(object sender, EventArgs e) {
        baseDataPath = this.MapPath("~/App_Data");
        BtnExportHideAndShow(false);
    }

    private void InitSessionObjects() {
    }

    protected void Page_Load(object sender, EventArgs e) {
        string sql = BuildSql();
    }


    protected void Page_Unload(object sender, EventArgs e) {
    }

    protected void LoadBtn_Click(object sender, EventArgs e)
    {
    }

    protected void SaveBtn_Click(object sender, EventArgs e){
    }

    private string BuildSql() {
        DbQuery query = (DbQuery)Session["EQ_QUERY"]; //getting model stored in sesson
        if (query != null) {
            SqlQueryBuilder builder = new SqlQueryBuilder(query);
            if (builder.CanBuild) {
                builder.BuildSQL();
                return builder.Result.SQL;
            }
            else
                return "";
        }
        else
            return "";

    }

    protected void ClearBtn_Click(object sender, EventArgs e){
        ResultGrid.Columns.Clear();
        ResultLabel.Text = string.Empty;
        BtnExportHideAndShow(false);
    }

    protected void CheckConnection() {
        if (DbConnection == null) {
            DbConnection = new OleDbConnection();
            DbConnection.ConnectionString = "Provider=Microsoft.Jet.OLEDB.4.0;Data Source=" +
               System.IO.Path.Combine(baseDataPath, "Nwind.mdb") + ";Persist Security Info=False";
            DbConnection.Open();
        }
    }

    private bool IsXAxisType(Type type) {
        return type.Equals(typeof(System.String));
    }

    private bool IsNumericType(Type type) {
        switch (Type.GetTypeCode(type)) {
            case TypeCode.Byte:
            case TypeCode.SByte:
            case TypeCode.UInt16:
            case TypeCode.UInt32:
            case TypeCode.UInt64:
            case TypeCode.Int16:
            case TypeCode.Int32:
            case TypeCode.Int64:
            case TypeCode.Decimal:
            case TypeCode.Double:
            case TypeCode.Single:
                return true;
            default:
                return false;
        }
    }

    protected void UpdateResultBtn_Click(object sender, EventArgs e) {
        try {
            ResultDS.SelectCommand = BuildSql();


            DataView view = (DataView)ResultDS.Select(DataSourceSelectArguments.Empty);

            DataColumn xCol = null, yCol = null;
            foreach (DataColumn col in view.Table.Columns) {
                if (xCol == null && IsXAxisType(col.DataType)) {
                    xCol = col;
                }
                if (yCol == null && IsNumericType(col.DataType)) {
                    yCol = col;
                }

                if (xCol != null && yCol != null) break;
            }

            if (xCol != null && yCol != null) {
                Chart1.Series[0].XValueMember = xCol.ColumnName;
                Chart1.Series[0].YValueMembers = yCol.ColumnName;
            }

            ResultLabel.Visible = false;
            ResultGrid.Visible = true;
            BtnExportHideAndShow(true);
        }
        catch (Exception ex) {
            ResultGrid.Visible = false;
            ResultLabel.Width = new Unit("100%");
            ResultLabel.Text = "Error in SQL statement: " + ex.Message;
            ResultLabel.Visible = true;

        }
    }


    protected void ExportExcelBtn_Click(object sender, EventArgs e) {
       
        ExportResultToExcel("result.xls");
    }

    protected void ExportResultToCSV(string fileName) {
        ResultDS.SelectCommand = BuildSql();
        DataView view = (DataView)ResultDS.Select(DataSourceSelectArguments.Empty);
        if (view == null) return;
        Response.Clear();
        Response.ContentType = "text/csv";
        Response.AddHeader("Content-Disposition",
            string.Format("attachment; filename=\"{0}\"", HttpUtility.UrlEncodeUnicode(fileName)));
        DbExport.ExportToCsv(view.Table, Response.Output, CsvFormats.Default);
        Response.End();
    }



    protected void ExportResultToExcel(string fileName) {
        ResultDS.SelectCommand = BuildSql();
        DataView view = (DataView)ResultDS.Select(DataSourceSelectArguments.Empty);
        if (view == null) return;
        this.EnableViewState = false;
        Response.Clear();
        Response.ContentType = "application/vnd.ms-excel";
        Response.AddHeader("Content-Disposition",
        string.Format("attachment; filename=\"{0}\"", HttpUtility.UrlEncodeUnicode(fileName)));
        DbExport.ExportToExcelHtml(view.Table, Response.Output, HtmlFormats.Default);
        Response.End();
    }

    public override void VerifyRenderingInServerForm(Control control) {
		//it is necessary for "Export to Excel" operation
        //we just ignore this event for GridView and do in usual way for all other controls
        if (!(control is GridView) && !(control is CheckBox))
            base.VerifyRenderingInServerForm(control);
    }

    protected void ExportCsvBtn_Click(object sender, EventArgs e){
         ExportResultToCSV("result.csv");
    }

    private void BtnExportHideAndShow(bool isActiv) {
        if (isActiv){
            btnExportExcel.Visible = true;
            btnExportCsv.Visible = true;
        }
        else{
            btnExportExcel.Visible = false;
            btnExportCsv.Visible = false;
        }
    }
}
